%% set_grid
%    allows accessing objects to set the grid variables to the
%    inputed objects
% inputs:
%   obj:GUI - current GUI object
%   grid2:Grid - Grid on the left
%   grid1:Grid - Grid on the top
%   grid0:RGrid - Results grid
% outputs:
%   none
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function [] = set_grid(object,grid2,grid1,grid0)
object.Grid2 = grid2;
object.Grid1 = grid1;
object.Grid0 = grid0;
end

